@@ -435,7 +435,11 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         acl_users = getattr(self, 'acl_users')
         user = acl_users.getUserById(userid)
         if user is None:
-            raise KeyError, 'Only retrievable users in this site can be made owners.'
+            # The user could be in the top level acl_users folder in
+            # the Zope root, in which case this should find him:
+            user = membership.getMemberById(userid)
+            if user is None:
+                raise KeyError, 'Only retrievable users in this site can be made owners.'
         object.changeOwnership(user, recursive)
 
         def fixOwnerRole(object, user_id):
@@ -626,7 +630,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         """
         if request is None:
             request = self.REQUEST
-        return utils.isDefaultPage(obj, request, context=self)
+        return utils.isDefaultPage(obj, request)
 
     security.declarePublic('getDefaultPage')
     def getDefaultPage(self, obj, request=None):
@@ -648,7 +652,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         """
         if request is None:
             request = self.REQUEST
-        return utils.getDefaultPage(obj, request, context=self)
+        return utils.getDefaultPage(obj, request)
 
     security.declarePublic('addPortalMessage')
     def addPortalMessage(self, message, type='info', request=None):
@@ -1009,13 +1013,9 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
 
         normalizeString() uses normalizeUnicode() to convert stray unicode
         characters. it will attempt to transliterate many of the accented
-        letters to rough ASCII equivalents:
-
-        >>> ptool.normalizeString(u"Eksempel \xe6\xf8\xe5 norsk \xc6\xd8\xc5")
-        'eksempel-eoa-norsk-eoa'
-
-        for characters that we can't transliterate, we just return the hex codes of
-        the byte(s) in the character. not pretty, but about the best we can do.
+        letters to rough ASCII equivalents for characters that we can't
+        transliterate, we just return the hex codes of the byte(s) in the
+        character. not pretty, but about the best we can do.
 
         >>> ptool.normalizeString(u"\u9ad8\u8054\u5408 Chinese")
         '9ad880545408-chinese'
@@ -1151,8 +1151,12 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
         cataloged_objs = cat(path = {'query':'/'.join(parent.getPhysicalPath()),
                                      'depth': 1})
         for brain in cataloged_objs:
-            obj = brain.getObject()
-            # Don't crash when the catalog has contains a stale entry
+            # Don't crash when the catalog contains a stale entry
+            try:
+                obj = brain.getObject()
+            except KeyError: # getObject raises since Zope 2.8
+                obj = None
+
             if obj is not None:
                 cat.reindexObject(obj,['getObjPositionInParent'],
                                                     update_metadata=0)
@@ -1306,7 +1310,7 @@ class PloneTool(PloneBaseTool, UniqueObject, SimpleItem):
                     failure[path]= e
                 else:
                     raise
-        transaction_note('Renamed %s' % str(success.keys))
+        transaction_note('Renamed %s' % str(success.keys()))
         return success, failure
     renameObjectsByPaths = postonly(renameObjectsByPaths)
 
