@@ -1,4 +1,5 @@
 import re
+import warnings
 from types import ClassType
 from os.path import join, abspath, split
 from cStringIO import StringIO
@@ -86,27 +87,31 @@ def _getDefaultPageView(obj, request):
     return view
 
 def isDefaultPage(obj, request, context=None):
+    if context is not None:
+        warnings.warn("The context parameter for isDefaultPage is "
+                      "deprecated and will be removed in Plone 4.",
+                      DeprecationWarning, 1)
     container = parent(obj)
     if container is None:
         return False
     view = _getDefaultPageView(container, request)
-    if context is None:
-        context = obj
-    return view.isDefaultPage(obj, context)
+    return view.isDefaultPage(obj)
 
 def getDefaultPage(obj, request, context=None):
+    if context is not None:
+        warnings.warn("The context parameter for getDefaultPage is "
+                      "deprecated and will be removed in Plone 4.",
+                      DeprecationWarning, 1)
     # Short circuit if we are not looking at a Folder
     if not obj.isPrincipiaFolderish:
         return None
     view = _getDefaultPageView(obj, request)
-    if context is None:
-        context = obj
-    return view.getDefaultPage(context)
+    return view.getDefaultPage()
 
 def isIDAutoGenerated(context, id):
     # In 2.1 non-autogenerated is the common case, caught exceptions are
     # expensive, so let's make a cheap check first
-    if id.count('.') != 2:
+    if id.count('.') < 2:
         return False
 
     pt = getToolByName(context, 'portal_types')
@@ -114,7 +119,10 @@ def isIDAutoGenerated(context, id):
     portaltypes.extend([pt.lower() for pt in portaltypes])
 
     try:
-        obj_type, date_created, random_number = id.split('.')
+        parts = id.split('.')
+        random_number = parts.pop()
+        date_created = parts.pop()
+        obj_type = '.'.join(parts)
         type = ' '.join(obj_type.split('_'))
         # New autogenerated ids may have a lower case portal type
         if ((type in portaltypes or obj_type in portaltypes) and
