@@ -12,7 +12,7 @@
 ##############################################################################
 """ Classes:  SetupTool
 
-$Id: tool.py 84623 2008-03-12 20:45:06Z wichert $
+$Id: tool.py 85170 2008-04-08 21:13:10Z wichert $
 """
 
 import os
@@ -1166,12 +1166,15 @@ class SetupTool(Folder):
         
         results = []
 
+        detect_steps = steps is None
+
         for profile_id in chain:
             context = self._getImportContext(profile_id, purge_old, archive)
             self.applyContext(context)
 
-            if steps is None:
+            if detect_steps:
                 steps = self.getSortedImportSteps()
+
             messages = {}
 
             event.notify(BeforeProfileImportEvent(self, profile_id, steps, True))
