@@ -149,7 +149,7 @@ class PlacelessTranslationService(Folder):
     # -3 for alpha, -2 for beta, -1 for release candidate
     # use an internal of > 99 to recreate the PTS at every startup
     # (development mode)
-    _class_version = (1, 4, 12, 0)
+    _class_version = (1, 4, 13, 0)
     all_meta_types = ()
 
     security = ClassSecurityInfo()
@@ -200,10 +200,10 @@ class PlacelessTranslationService(Folder):
         """Calulate the po id
         """
         # instance, software and global catalog path for i18n and locales
-        iPath       = os.path.join(INSTANCE_HOME, 'Products') + os.sep
-        sPath       = os.path.join(SOFTWARE_HOME, 'Products') + os.sep
-        gci18nNPath = os.path.join(INSTANCE_HOME, 'i18n')
-        gcLocPath   = os.path.join(INSTANCE_HOME, 'locales')
+        iPath       = os.path.join(Globals.INSTANCE_HOME, 'Products') + os.sep
+        sPath       = os.path.join(Globals.SOFTWARE_HOME, 'Products') + os.sep
+        gci18nNPath = os.path.join(Globals.INSTANCE_HOME, 'i18n')
+        gcLocPath   = os.path.join(Globals.INSTANCE_HOME, 'locales')
 
         # a global catalog is
         isGlobalCatalog = False
