@@ -1,5 +1,5 @@
 """
-$Id: __init__.py 66780 2008-06-17 12:47:32Z hannosch $
+$Id: __init__.py 69676 2008-08-09 09:04:27Z hannosch $
 """
 
 import os
@@ -7,6 +7,7 @@ from zope.deprecation import deprecate
 
 from Products.PageTemplates.GlobalTranslationService import \
     setGlobalTranslationService
+from Globals import package_home
 import Globals
 pts_globals = globals()
 
@@ -143,18 +144,29 @@ def initialize(context):
         cp_ts = make_translation_service(cp)
 
     # sweep products
-    log('products: %r' % cp.Products.objectValues(), logging.DEBUG)
-    for prod in cp.Products.objectValues():
-        # prod is a Product object:
-        # (priority, dir_name, index, base_dir) for each Product directory
-        cp_ts._load_i18n_dir(os.path.join(prod.home, 'i18n'))
+    products = [getattr(p, 'package_name', 'Products.' + p.id) for
+                p in cp.Products.objectValues() if
+                getattr(p, 'thisIsAnInstalledProduct', False)]
+    # Sort the products by lower-cased package name to gurantee a stable
+    # load order
+    products.sort(key=lambda p: p.lower())
+    log('products: %r' % products, logging.DEBUG)
+    for prod in products:
+        # prod is a package name, we fake a globals dict with it
+        try:
+            prod_path = package_home({'__name__' : prod})
+            cp_ts._load_i18n_dir(os.path.join(prod_path, 'i18n'))
+        except KeyError:
+            log("You have a stale entry for '%s' in your ZMI Products section."
+                "You should consider removing it." % prod, logging.INFO)
+            continue
 
     # sweep the i18n directory for local catalogs
-    instance_i18n = os.path.join(INSTANCE_HOME, 'i18n')
+    instance_i18n = os.path.join(Globals.INSTANCE_HOME, 'i18n')
     if os.path.isdir(instance_i18n):
         cp_ts._load_i18n_dir(instance_i18n)
 
-    instance_locales = os.path.join(INSTANCE_HOME, 'locales')
+    instance_locales = os.path.join(Globals.INSTANCE_HOME, 'locales')
     if os.path.isdir(instance_locales):
         cp_ts._load_locales_dir(instance_locales)
 
