@@ -7,7 +7,7 @@
  * Contributors see CREDITS.txt.
  *
  *****************************************************************************/
-// $Id: kupudrawers.js 54915 2008-05-19 08:33:27Z duncan $
+// $Id: kupudrawers.js 58437 2008-09-25 15:36:23Z mihxil $
 
 function kupu_busy(ed) {
     if (ed.busy) ed.busy();
@@ -63,7 +63,7 @@ function DrawerTool() {
         this.current_drawer.hide();
         this.current_drawer.editor.resumeEditing();
         this.current_drawer = null;
-        kupu_notbusy(this.editor, true)
+        kupu_notbusy(this.editor, true);
     };
 };
 
@@ -155,9 +155,9 @@ proto.switchMode = function(event) {
     event = event || window.event;
     var target = event.currentTarget || event.srcElement;
     var el = target;
-    while (!/^li$/i.test(el.nodeName)) { el = el.parentNode; };
+    while (!(/^li$/i.test(el.nodeName))) { el = el.parentNode; };
     var thistab = el;
-    while (!/^ul$/i.test(el.nodeName)) { el = el.parentNode; };
+    while (!(/^ul$/i.test(el.nodeName))) { el = el.parentNode; };
     var tabs = el.getElementsByTagName('li');
     for (var i = 0; i < tabs.length; i++) {
         var el = tabs[i];
@@ -276,6 +276,7 @@ proto.anchorframe_loaded = function() {
 
 proto.showAnchors = function(selected) {
     var select = this.anchorSelect();
+    if (select == undefined) return;
     var opts = select.options;
 
     while (opts.length > 1) opts[1] = null;
@@ -664,6 +665,9 @@ function LibraryDrawer(tool, xsluri, libsuri, searchuri, baseelement, selecturi)
         LibraryDrawer.prototype.hide.call(this);
     };
 
+
+
+
     /*** bootstrapping ***/
 
     this._libsXslCallback = function(dom) {
@@ -801,8 +805,8 @@ function LibraryDrawer(tool, xsluri, libsuri, searchuri, baseelement, selecturi)
         for (var k in this.options) {
             xsltproc.setParameter("", k, this.options[k]);
         }
-        xsltproc.setParameter("", "multiple", this.multiple?"yes":"");
-        xsltproc.setParameter("", "showupload", this.showupload);
+        xsltproc.setParameter("", "multiple", this.multiple ? "yes" : "");
+        xsltproc.setParameter("", "showupload", this.showupload ? "yes" : "");
         xsltproc.setParameter("", "showanchors", this.showanchors);
 
         var doc = this._transformXml();
@@ -1436,14 +1440,18 @@ function ImageLibraryDrawer(tool, xsluri, libsuri, searchuri, baseelement, selec
     // upload, on submit/insert press
     this.uploadImage = function() {
         var form = document.getElementById('kupu_upload_form');
-        if (!form || form.node_prop_image.value=='') return;
+        if (!form || (form.node_prop_image && form.node_prop_image.value == '')) {
+            return;
+        }
 
-        if (form.node_prop_title.value == "") {
+        if (form.node_prop_title && form.node_prop_title.value == "") {
             alert("Please enter a title for the image you are uploading");
             return;
         };
-        this.upload_title = form.node_prop_title.value;
-        form.node_prop_desc.value = form.node_prop_desc.value.replace(/^\xa0|\xa0$/g,'');
+        this.upload_title = form.node_prop_title ? form.node_prop_title.value : '';
+        if (form.node_prop_desc) {
+            form.node_prop_desc.value = form.node_prop_desc.value.replace(/^\xa0|\xa0$/g,'');
+        }
         form.submit();
     };
 
@@ -1631,7 +1639,6 @@ function AnchorDrawer(elementid, tool) {
         if (/kupu-ins-bm/.test(this.panel.className)) return 0;
         if (/kupu-anchor/.test(this.panel.className)) return 1;
         return 2;
-        return !!(/kupu-ins-bm/.test(this.panel.className));
     };
 
     this.checkAll = function() {
@@ -1798,7 +1805,6 @@ AnchorDrawer.prototype = new Drawer;
 function HandleDrawerEnter(event, clickid) {
     event = event || window.event;
     var key = event.which || event.keyCode;
-    var target = event.currentTarget || event.srcElement;
     var button;
     if (key==13) {
         if (clickid) {
