@@ -13,7 +13,7 @@
 This module contains the Plone specific version of the Kupu library
 tool.
 
-$Id: plonelibrarytool.py 53093 2008-03-29 15:33:33Z duncan $
+$Id: plonelibrarytool.py 58620 2008-10-06 09:46:29Z duncan $
 """
 import os
 from ZODB.PersistentList import PersistentList
@@ -856,7 +856,7 @@ class PloneKupuLibraryTool(UniqueObject, SimpleItem, KupuLibraryTool,
         if captioning is not None:
             self.captioning = bool(captioning)
 
-        if self.linkbyuid or self.captioning:
+        if self.linkbyuid or self.getCaptioning():
             util.install_transform(self)
         else:
             util.remove_transform(self)
