@@ -7,7 +7,7 @@
  * Contributors see CREDITS.txt.
  *
  *****************************************************************************/
-// $Id: kupuinit.js 54930 2008-05-19 13:22:26Z guido $
+// $Id: kupuinit.js 55333 2008-05-28 10:56:35Z guido $
 
 // XXX Port this to the default dist?
 KupuEditor.prototype.afterInit = function() {
@@ -259,7 +259,36 @@ function initKupu(iframe) {
         b.parentNode.removeChild(b);
     };
 
+    if (!tools || !tools.length || tools.contains('link')) {
+        var linktool = new LinkTool();
+        kupu.registerTool('link', linktool);
+        var handler = function(e) {
+            linktool.createLinkHandler(e);
+        };
+        addEventHandler(document.getElementById('kupu-popup-intlink-button'),
+                        'click', handler);
+    } else {
+        var b = document.getElementById('kupu-popup-intlink-button');
+        b.parentNode.removeChild(b);
+    };
+
+    if (!tools || !tools.length || tools.contains('image')) {
+        var imagetool = new ImageTool();
+        kupu.registerTool('image', imagetool);
+        var handler = function(e) {
+            imagetool.createImageHandler(e);
+        };
+        addEventHandler(document.getElementById('kupu-popup-image-button'),
+                        'click', handler);
+    } else {
+        var b = document.getElementById('kupu-popup-image-button');
+        b.parentNode.removeChild(b);
+    };
+
     if (!tools || !tools.length || tools.contains('browser')) {
+        parent.browser_manager.widgeteerpath =
+            parentiframe.textarea.getAttribute('widget:widgeteerpath') ||
+            '../../';
         var linktool = new LinkTool();
         kupu.registerTool('linktool', linktool);
         var handler = function() {
@@ -437,20 +466,8 @@ function initKupu(iframe) {
     drawertool.registerDrawer('tabledrawer', tabledrawer);
     */
 
-//    var nonxhtmltagfilter = new NonXHTMLTagFilter();
-//    kupu.registerFilter(nonxhtmltagfilter);
-
-    kupu.xhtmlvalid.setAttrFilter(['is_toc', 'toc_depth', 'is_citation', 
-                                    'source', 'author', 'source_id', 
-                                    'silva_type', 'alignment', 
-                                    'link_to_hires', 'link']);
-    // allow all attributes on div, since ExternalSources require that
-    kupu.xhtmlvalid.includeTagAttributes(['div'], ['*']);
-    kupu.xhtmlvalid.includeTagAttributes(['p'], ['silva_type']);
-    kupu.xhtmlvalid.includeTagAttributes(['h6'], ['silva_type']);
-    kupu.xhtmlvalid.includeTagAttributes(['img'], ['alignment', 
-                                            'link_to_hires', 
-                                            'target', 'link']);
+    var nonxhtmltagfilter = new NonXHTMLTagFilter();
+    kupu.registerFilter(nonxhtmltagfilter);
 
     return kupu;
 }
