@@ -78,7 +78,7 @@ class TestDisplayMenu(ptc.PloneTestCase):
         self.folder.invokeFactory('Document', 'doc1')
         self.folder.setDefaultPage('doc1')
         actions = self.menu.getMenuItems(self.folder.doc1, self.request)
-        self.failUnless('_folderDefaultPageDisplay' in [a['extra']['id'] for a in actions])
+        self.failUnless('folderDefaultPageDisplay' in [a['extra']['id'] for a in actions])
         self.failIf('document_view' in [a['extra']['id'] for a in actions])
 
     def testDefaultPageIncludesParentAndItemViewsWhenItemHasMultipleViews(self):
@@ -88,7 +88,7 @@ class TestDisplayMenu(ptc.PloneTestCase):
         self.folder.invokeFactory('Document', 'doc1')
         self.folder.setDefaultPage('doc1')
         actions = self.menu.getMenuItems(self.folder.doc1, self.request)
-        self.failUnless('_folderDefaultPageDisplay' in [a['extra']['id'] for a in actions])
+        self.failUnless('folderDefaultPageDisplay' in [a['extra']['id'] for a in actions])
         self.failUnless('document_view' in [a['extra']['id'] for a in actions])
         self.failUnless('base_view' in [a['extra']['id'] for a in actions])
 
@@ -104,40 +104,40 @@ class TestDisplayMenu(ptc.PloneTestCase):
         self.folder.invokeFactory('Folder', 'f1')
         self.failUnless(self.folder.f1.canSetDefaultPage())
         actions = self.menu.getMenuItems(self.folder.f1, self.request)
-        self.failUnless('_contextSetDefaultPage' in [a['extra']['id'] for a in actions])
+        self.failUnless('contextSetDefaultPage' in [a['extra']['id'] for a in actions])
 
     def testWithCanSetDefaultPageFalse(self):
         self.folder.invokeFactory('Folder', 'f1')
         self.folder.f1.manage_permission('Modify view template', ('Manager',))
         self.failIf(self.folder.f1.canSetDefaultPage())
         actions = self.menu.getMenuItems(self.folder.f1, self.request)
-        self.failIf('_contextSetDefaultPage' in [a['extra']['id'] for a in actions])
+        self.failIf('contextSetDefaultPage' in [a['extra']['id'] for a in actions])
 
     def testSelectItemNotIncludedInNonStructuralFolder(self):
         self.folder.invokeFactory('Folder', 'f1')
         directlyProvides(self.folder.f1, INonStructuralFolder)
         actions = self.menu.getMenuItems(self.folder.f1, self.request)
-        self.failIf('_contextSetDefaultPage' in [a['extra']['id'] for a in actions])
+        self.failIf('contextSetDefaultPage' in [a['extra']['id'] for a in actions])
 
     def testDefaultPageSelectedAndOverridesLayout(self):
         self.folder.invokeFactory('Document', 'doc1')
         self.folder.setDefaultPage('doc1')
         actions = self.menu.getMenuItems(self.folder, self.request)
         selected = [a['extra']['id'] for a in actions if a['selected']]
-        self.assertEqual(selected, ['_contextDefaultPageDisplay'])
+        self.assertEqual(selected, ['contextDefaultPageDisplay'])
 
     def testDefaultPageCanBeChangedInContext(self):
         self.folder.invokeFactory('Document', 'doc1')
         self.folder.setDefaultPage('doc1')
         actions = self.menu.getMenuItems(self.folder, self.request)
-        self.failUnless('_contextChangeDefaultPage' in [a['extra']['id'] for a in actions])
+        self.failUnless('contextChangeDefaultPage' in [a['extra']['id'] for a in actions])
 
     def testDefaultPageCanBeChangedInFolder(self):
         self.folder.invokeFactory('Document', 'doc1')
         self.folder.setDefaultPage('doc1')
         actions = self.menu.getMenuItems(self.folder.doc1, self.request)
-        self.failUnless('_folderChangeDefaultPage' in [a['extra']['id'] for a in actions])
-        self.failIf('_contextChangeDefaultPage' in [a['extra']['id'] for a in actions])
+        self.failUnless('folderChangeDefaultPage' in [a['extra']['id'] for a in actions])
+        self.failIf('contextChangeDefaultPage' in [a['extra']['id'] for a in actions])
 
     # Headers/separators
 
@@ -149,8 +149,8 @@ class TestDisplayMenu(ptc.PloneTestCase):
         self.folder.setDefaultPage('doc1')
         actions = self.menu.getMenuItems(self.folder.doc1, self.request)
         ids = [a['extra']['id'] for a in actions]
-        self.failUnless('_folderHeader' in ids)
-        self.failUnless('_contextHeader' in ids)
+        self.failUnless('folderHeader' in ids)
+        self.failUnless('contextHeader' in ids)
 
     def testSeparatorsNotIncludedWhenViewingDefaultPageWithoutViews(self):
         self.folder.invokeFactory('Document', 'doc1')
@@ -158,8 +158,8 @@ class TestDisplayMenu(ptc.PloneTestCase):
         self.assertEqual(len(self.folder.doc1.getAvailableLayouts()), 1)
         actions = self.menu.getMenuItems(self.folder.doc1, self.request)
         ids = [a['extra']['id'] for a in actions]
-        self.failIf('_folderHeader' in ids)
-        self.failIf('_contextHeader' in ids)
+        self.failIf('folderHeader' in ids)
+        self.failIf('contextHeader' in ids)
 
     def testSeparatorsNotDisplayedWhenViewingFolder(self):
         fti = self.portal.portal_types['Document']
@@ -169,15 +169,15 @@ class TestDisplayMenu(ptc.PloneTestCase):
         self.folder.setDefaultPage('doc1')
         actions = self.menu.getMenuItems(self.folder, self.request)
         ids = [a['extra']['id'] for a in actions]
-        self.failIf('_folderHeader' in ids)
-        self.failIf('_contextHeader' in ids)
+        self.failIf('folderHeader' in ids)
+        self.failIf('contextHeader' in ids)
 
     # Regressions
 
     def testDefaultPageTemplateTitle(self):
         self.folder.setDefaultPage('sitemap') # Use a template in portal_skins
         actions = self.menu.getMenuItems(self.folder, self.request)
-        changeAction = [x for x in actions if x['extra']['id'] == '_contextDefaultPageDisplay'][0]
+        changeAction = [x for x in actions if x['extra']['id'] == 'contextDefaultPageDisplay'][0]
         changeAction['title'].default
         self.assertEquals(u"Sitemap", changeAction['title'].mapping['contentitem'])
 
@@ -220,6 +220,12 @@ class TestFactoriesMenu(ptc.PloneTestCase):
     def testNoAddableTypes(self):
         actions = self.menu.getMenuItems(self.portal, self.request)
         self.assertEqual(len(actions), 0)
+        
+        # set no types for folders and check the menu is not shown
+        folder_fti = self.portal.portal_types['Folder']
+        folder_fti.manage_changeProperties(filter_content_types=True, allowed_content_types=[])
+        actions = self.menu.getMenuItems(self.folder, self.request)
+        self.assertEqual(len(actions), 0)
 
     def testConstrainTypes(self):
         constraints = ISelectableConstrainTypes(self.folder)
@@ -229,11 +235,11 @@ class TestFactoriesMenu(ptc.PloneTestCase):
         actions = self.menu.getMenuItems(self.folder, self.request)
         self.assertEqual(len(actions), 2)
         self.assertEqual(actions[0]['extra']['id'], 'document')
-        self.assertEqual(actions[1]['extra']['id'], '_settings')
+        self.assertEqual(actions[1]['extra']['id'], 'settings')
 
     def testSettingsIncluded(self):
         actions = self.menu.getMenuItems(self.folder, self.request)
-        self.assertEqual(actions[-1]['extra']['id'], '_settings')
+        self.assertEqual(actions[-1]['extra']['id'], 'settings')
 
     def testSettingsNotIncludedWhereNotSupported(self):
         self.folder.manage_permission('Modify constrain types', ('Manager',))
@@ -248,8 +254,8 @@ class TestFactoriesMenu(ptc.PloneTestCase):
         actions = self.menu.getMenuItems(self.folder, self.request)
         self.failIf('image' in [a['extra']['id'] for a in actions])
         self.failUnless('document' in [a['extra']['id'] for a in actions])
-        self.failUnless('_more' in [a['extra']['id'] for a in actions])
-        self.failUnless('_settings' in [a['extra']['id'] for a in actions])
+        self.failUnless('more' in [a['extra']['id'] for a in actions])
+        self.failUnless('settings' in [a['extra']['id'] for a in actions])
 
     def testMoreNotIncludedWhenNotNecessary(self):
         constraints = ISelectableConstrainTypes(self.folder)
@@ -259,7 +265,7 @@ class TestFactoriesMenu(ptc.PloneTestCase):
         actions = self.menu.getMenuItems(self.folder, self.request)
         self.assertEqual(len(actions), 2)
         self.assertEqual(actions[0]['extra']['id'], 'document')
-        self.assertEqual(actions[1]['extra']['id'], '_settings')
+        self.assertEqual(actions[1]['extra']['id'], 'settings')
 
     def testNonStructualFolderShowsParent(self):
         # Cope with an unfortunate side-effect of running all plone.* tests at
@@ -386,14 +392,14 @@ class TestContentMenu(ptc.PloneTestCase):
     def testDisplayMenuDisabledIfIndexHtmlInFolder(self):
         self.folder.invokeFactory('Document', 'index_html')
         items = self.menu.getMenuItems(self.folder, self.request)
-        displayMenuItem = [i for i in items if i['extra']['id'] == 'plone-contentmenu-display'][0]
-        self.assertEqual(displayMenuItem['extra']['disabled'], True)
+        displayMenuItems = [i for i in items if i['extra']['id'] == 'plone-contentmenu-display']
+        self.assertEqual(len(displayMenuItems), 0)
 
     def testDisplayMenuDisabledIfIndexHtmlInFolderAndContextIsIndexHtml(self):
         self.folder.invokeFactory('Document', 'index_html')
         items = self.menu.getMenuItems(self.folder.index_html, self.request)
-        displayMenuItem = [i for i in items if i['extra']['id'] == 'plone-contentmenu-display'][0]
-        self.assertEqual(displayMenuItem['extra']['disabled'], True)
+        displayMenuItems = [i for i in items if i['extra']['id'] == 'plone-contentmenu-display']
+        self.assertEqual(len(displayMenuItems), 0)
 
     # Add sub-menu
 
@@ -416,7 +422,7 @@ class TestContentMenu(ptc.PloneTestCase):
         items = self.menu.getMenuItems(self.folder, self.request)
         factoriesMenuItem = [i for i in items if i['extra']['id'] == 'plone-contentmenu-factories'][0]
         self.assertEqual(len(factoriesMenuItem['submenu']), 1)
-        self.assertEqual(factoriesMenuItem['submenu'][0]['extra']['id'], '_settings')
+        self.assertEqual(factoriesMenuItem['submenu'][0]['extra']['id'], 'settings')
 
     def testAddMenuWithNothingToAddButWithAvailableMorePage(self):
         self.folder.setConstrainTypesMode(1)
@@ -426,7 +432,7 @@ class TestContentMenu(ptc.PloneTestCase):
         items = self.menu.getMenuItems(self.folder, self.request)
         factoriesMenuItem = [i for i in items if i['extra']['id'] == 'plone-contentmenu-factories'][0]
         self.assertEqual(len(factoriesMenuItem['submenu']), 1)
-        self.assertEqual(factoriesMenuItem['submenu'][0]['extra']['id'], '_more')
+        self.assertEqual(factoriesMenuItem['submenu'][0]['extra']['id'], 'more')
 
     def testAddMenuRelativeToNonStructuralFolder(self):
         self.folder.invokeFactory('Folder', 'f1')
