@@ -117,7 +117,7 @@ class SharingView(BrowserView):
             if permission is None or portal_membership.checkPermission(permission, context):
                 pairs.append(dict(id = name, title = utility.title))
                 
-        pairs.sort(lambda x, y: cmp(x['id'], y['id']))
+        pairs.sort(key=lambda x: x["id"])
         return pairs
         
     @memoize
@@ -147,18 +147,23 @@ class SharingView(BrowserView):
         # merge those into the role settings.
         requested = self.request.form.get('entries', None)
         if requested is not None:
-            roles = [r['id'] for r in self.roles()]
+            knownroles = [r['id'] for r in self.roles()]
             settings = {}
             for entry in requested:
-                roles = [r for r in roles if entry.get('role_%s' % r, False)]
+                roles = [r for r in knownroles
+                                if entry.get('role_%s' % r, False)]
                 settings[(entry['id'], entry['type'])] = roles
 
             for entry in current_settings:
                 desired_roles = settings.get((entry['id'], entry['type']), None)
+
                 if desired_roles is None:
                     continue
                 for role in entry["roles"]:
-                    entry["roles"][role] = role in desired_roles
+                    if entry["roles"][role] in [True, False]:
+                        entry["roles"][role] = role in desired_roles
+
+        current_settings.sort(key=lambda x: x["type"]+str(x["title"]))
 
         return current_settings
 
