@@ -12,7 +12,8 @@ from zope.interface import implements
 FILENAME_REGEX = re.compile(r"^(.+)\.(\w{,4})$")
 IGNORE_REGEX = re.compile(r"['\"]")
 NON_WORD_REGEX = re.compile(r"[\W\-]+")
-DANGEROUS_CHARS_REGEX = re.compile(r"[!#$%&()*+,/:;<=>?@\\^_{|}\[\]~`]+")
+DANGEROUS_CHARS_REGEX = re.compile(r"[!$%&()*+,/:;<=>?@\\^{|}\[\]~`]+")
+URL_DANGEROUS_CHARS_REGEX = re.compile(r"[!#$%&()*+,/:;<=>?@\\^{|}\[\]~`]+")
 MULTIPLE_DASHES_REGEX = re.compile(r"\-+")
 EXTRA_DASHES_REGEX = re.compile(r"(^\-+)|(\-+$)")
 #Define static constraints
@@ -186,7 +187,7 @@ class URLNormalizer(object):
 
         base = base.replace(' ', '-')
         base = IGNORE_REGEX.sub('', base)
-        base = DANGEROUS_CHARS_REGEX.sub('-', base)
+        base = URL_DANGEROUS_CHARS_REGEX.sub('-', base)
         base = EXTRA_DASHES_REGEX.sub('', base)
         base = MULTIPLE_DASHES_REGEX.sub('-', base)
 
