@@ -43,7 +43,7 @@ def testIDNormalizer():
       'here-s-yet-another'
 
       >>> util.normalize(unicode("umläut.doc", 'utf-8'))
-      'umlaut.doc'
+      'umlaeut.doc'
 
       >>> from plone.i18n.normalizer import MAX_LENGTH
       
@@ -136,11 +136,11 @@ def testFileNameNormalizer():
       >>> util.normalize(u"{[(me too)]}")
       'me too'
 
-      >>> util.normalize("pseudo_filename,pot.doc")
-      'pseudo-filename-pot.doc'
+      >>> util.normalize("pseudo_filename,pot,#1.doc")
+      'pseudo_filename-pot-#1.doc'
 
       >>> util.normalize(unicode("umläut.doc", 'utf-8'))
-      'umlaut.doc'
+      'umlaeut.doc'
 
       >>> len(util.normalize(u'aa' * 2000))
       1023
@@ -204,7 +204,7 @@ def testURLNormalizer():
       'doe-joe'
 
       >>> util.normalize(unicode("umläut.doc", 'utf-8'))
-      'umlaut.doc'
+      'umlaeut.doc'
 
       >>> util.normalize('quote "this"!')
       'quote-this'
@@ -263,6 +263,7 @@ def test_suite():
         DocTestSuite('plone.i18n.normalizer.base'),
         DocTestSuite('plone.i18n.normalizer.de'),
         DocTestSuite('plone.i18n.normalizer.el'),
+        DocTestSuite('plone.i18n.normalizer.fr'),
         DocTestSuite('plone.i18n.normalizer.pl'),
         DocTestSuite('plone.i18n.normalizer.ru'),
         DocTestSuite('plone.i18n.normalizer.tr'),
